@@ -23,7 +23,6 @@
 #include <iv.h>
 #include <iv_event_raw.h>
 #include <unistd.h>
-#include "config.h"
 
 int iv_event_raw_register(struct iv_event_raw *this)
 {
@@ -48,7 +47,7 @@ void iv_event_raw_unregister(struct iv_event_raw *this)
 	CloseHandle(this->h.handle);
 }
 
-void iv_event_raw_post(struct iv_event_raw *this)
+void iv_event_raw_post(const struct iv_event_raw *this)
 {
 	SetEvent(this->h.handle);
 }
